// Load the data from the provided URL
d3.text("https://gist.githubusercontent.com/mandadi1999/732949a1ee08be84fed50a86eb123df7/raw/de9a34003f64773ca2d9b2a5b11a74d46cbdf9cc/gistfile1.txt").then(function(textData) {
  // Parse the text data into an array of objects
  const data = d3.csvParse(textData);

  // Set up dimensions for the chart
  const margin = { top: 30, right: 30, bottom: 70, left: 60 };
  const width = 600 - margin.left - margin.right;
  const height = 400 - margin.top - margin.bottom;

  // Create an SVG element and append it to the chart div
  const svg = d3.select("#chart")
    .append("svg")
    .attr("width", width + margin.left + margin.right)
    .attr("height", height + margin.top + margin.bottom)
    .append("g")
    .attr("transform", `translate(${margin.left},${margin.top})`);

  // Convert population data to numbers
  data.forEach(function(d) {
    d.population = +d.population;
  });

  // Create scales for x and y axes
  const xScale = d3.scaleBand()
    .domain(data.map(d => d.country))
    .range([0, width])
    .padding(0.2);

  const yScale = d3.scaleLinear()
    .domain([0, d3.max(data, d => d.population)])
    .range([height, 0]);

  // Create x and y axes
  const xAxis = d3.axisBottom(xScale);
  const yAxis = d3.axisLeft(yScale);

  // Append x and y axes to the SVG element
  svg.append("g")
    .attr("class", "x-axis")
    .attr("transform", `translate(0, ${height})`)
    .call(xAxis)
    .selectAll("text")
    .style("text-anchor", "end")
    .attr("dx", "-.8em")
    .attr("dy", ".15em")
    .attr("transform", "rotate(-65)");

  svg.append("g")
    .attr("class", "y-axis")
    .call(yAxis);

  // Create the bars
  svg.selectAll(".bar")
    .data(data)
    .enter()
    .append("rect")
    .attr("class", "bar")
    .attr("x", d => xScale(d.country))
    .attr("y", d => yScale(d.population))
    .attr("width", xScale.bandwidth())
    .attr("height", d => height - yScale(d.population));

  // Add labels to the bars
  svg.selectAll(".bar-label")
    .data(data)
    .enter()
    .append("text")
    .attr("class", "bar-label")
    .attr("x", d => xScale(d.country) + xScale.bandwidth() / 2)
    .attr("y", d => yScale(d.population) - 5)
    .attr("text-anchor", "middle")
    .text(d => d.population.toLocaleString()); // Formatting the population number with commas

  // Add a title to the chart
  svg.append("text")
    .attr("class", "chart-title")
    .attr("x", width / 2)
    .attr("y", -margin.top / 2)
    .attr("text-anchor", "middle")
    .text("Top Populous Countries");
});
